@@ -32,7 +32,6 @@
 #include <QUuid>
 
 // KDE
-#include <kdbusconnectionpool.h>
 #include <klocalizedstring.h>
 #include <kauthorized.h>
 #include <kdelibs4migration.h>
@@ -107,9 +106,9 @@ Activities::Private::Private(Activities *parent)
                                                       Activities::Running;
 
     const auto runningActivities
-        = mainConfig().readEntry("runningActivities", QStringList()).toSet();
+        = mainConfig().readEntry("runningActivities", QStringList());
     const auto stoppedActivities
-        = mainConfig().readEntry("stoppedActivities", QStringList()).toSet();
+        = mainConfig().readEntry("stoppedActivities", QStringList());
 
     // Do we have a running activity?
     bool atLeastOneRunning = false;
@@ -495,7 +494,7 @@ Activities::Activities(QObject *parent)
     // Initializing D-Bus service
 
     new ActivitiesAdaptor(this);
-    KDBusConnectionPool::threadConnection().registerObject(
+    QDBusConnection::sessionBus().registerObject(
         KAMD_DBUS_OBJECT_PATH(Activities), this);
 
     // Initializing config
